# Demos

This is a collection of notebooks and scripts that demonstrate how to use 'pyclesperanto' for image processing and analysis. They are here to show various use cases and to help you get started.

These are note exaustives and we are happy to add more. Please get in touch if you have a demo that you would like to share.

### pre-requisites

To run these demos, you need to have 'pyclesperanto' installed. If you don't have it yet, please follow the instructions [here](../README.md) or read the documentation [here](https://clesperanto.github.io/pyclesperanto_prototype/).

Most of the demos also require [scikit-image](https://scikit-image.org/) and [jupyter](https://jupyter.org/), which you can install via pip:

```bash
pip install scikit-image jupyterlab
```

or conda:

```bash
conda install scikit-image jupyterlab
```

# Warning

These demos are not meant to be used for benchmarking. They are meant to be easy to understand and to get you started. Several costly operations are done on purpose to make the code easier to understand. If you want to use pyclesperanto in production, please read the documentation and don't hesitate to get in touch with us to get help with optimizing your code.
